function adstat = xadtest(x)

%=============================================================
% PURPOSE: Anderson-Darling test for normality. F0 is assumed to be CDF of N(0,1)!
% 
% INPUT:
%   x: (Tx1) vector of obseravtions 
% 
% OUTPUT: 
% adstat
%=============================================================

% Calculate S(x), the sample CDF.
n = length(x);
x = zscore(x);
xCDF = sort(x);

% Compute the test statistic of interest under the null hypothesis F0 = N(0,1).
nullCDF  = normcdf(xCDF, 0, 1);
I = (1:n)';
J = (n:-1:1)';
adstat = -n - mean((2*I-1).*(log(nullCDF(I))+log(1-nullCDF(J))));

